BlockBitmaps

Struct BlockBitmaps 

pub struct BlockBitmaps {
    pub lt: u64,
    pub gt: u64,
    pub amp: u64,
    pub quot: u64,
    pub apos: u64,
    pub eq: u64,
    pub slash: u64,
    pub in_string: u64,
}
Per-block bitmasks for each HTML delimiter type.

Bit i of a mask is set if the byte at position i within the block matches that delimiter. After quote-aware masking, non-structural positions (inside quoted strings) are cleared from the relevant masks.

Fields

lt: u64

< positions.

gt: u64

> positions.

amp: u64

& positions.

quot: u64

" positions.

apos: u64

' positions.

eq: u64

= positions.

slash: u64

/ positions.

in_string: u64

Positions inside quoted strings (both " and '). Set bits indicate bytes that are not structural.